api_structures subpackage
=========================

.. toctree::

   /api/api_structures/catalog
   /api/api_structures/digital_instance
   /api/api_structures/digital_library
   /api/api_structures/kwarg_obj
   /api/api_structures/modes
   /api/api_structures/registrar
   /api/api_structures/tools
   /api/api_structures/urn_nbn
